=== modified file 'drizzled/daemon.cc'
--- drizzled/daemon.cc	2011-02-17 00:14:13 +0000
+++ drizzled/daemon.cc	2011-07-18 17:13:07 +0000
@@ -67,83 +67,84 @@
 
 void daemon_is_ready()
 {
+  int fd;
   kill(parent_pid, SIGUSR1);
+
+  if ((fd = open("/dev/null", O_RDWR, 0)) != -1) 
+  {
+    if(dup2(fd, STDIN_FILENO) < 0)
+    {
+      perror("dup2 stdin");
+      return;
+    }
+
+    if(dup2(fd, STDOUT_FILENO) < 0)
+    {
+      perror("dup2 stdout");
+      return;
+    }
+
+    if(dup2(fd, STDERR_FILENO) < 0)
+    {
+      perror("dup2 stderr");
+      return;
+    }
+
+    if (fd > STDERR_FILENO)
+    {
+      if (close(fd) < 0)
+      {
+        perror("close");
+        return;
+      }
+    }
+  }
 }
 
-bool daemonize(bool nochdir, bool noclose, bool wait_sigusr1)
+bool daemonize()
 {
-    int fd;
-    pid_t child= -1;
-
-    parent_pid= getpid();
-    signal(SIGUSR1, sigusr1_handler);
-
-    child= fork();
-
-    switch (child)
+  pid_t child= -1;
+
+  parent_pid= getpid();
+  signal(SIGUSR1, sigusr1_handler);
+
+  child= fork();
+
+  switch (child)
+  {
+  case -1:
+    return true;
+
+  case 0:
+    break;
+
+  default:
     {
-    case -1:
-        return true;
-    case 0:
-        break;
-    default:
-      if (wait_sigusr1)
-      {
-        /* parent */
-        int exit_code= -1;
-        int status;
-        while (waitpid(child, &status, 0) != child)
-        { }
-
-        if (WIFEXITED(status))
-        {
-          exit_code= WEXITSTATUS(status);
-        }
-        if (WIFSIGNALED(status))
-        {
-          exit_code= -1;
-        }
-        _exit(exit_code);
-      }
-      else
-      {
-        _exit(EXIT_SUCCESS);
-      }
-    }
-
-    /* child */
-    if (setsid() == -1)
-        return true;
-
-    if (nochdir == 0) {
-        if(chdir("/") != 0) {
-            perror("chdir");
-            return true;
-        }
-    }
-
-    if (noclose == 0 && (fd = open("/dev/null", O_RDWR, 0)) != -1) {
-        if(dup2(fd, STDIN_FILENO) < 0) {
-            perror("dup2 stdin");
-            return true;
-        }
-        if(dup2(fd, STDOUT_FILENO) < 0) {
-            perror("dup2 stdout");
-            return true;
-        }
-        if(dup2(fd, STDERR_FILENO) < 0) {
-            perror("dup2 stderr");
-            return true;
-        }
-
-        if (fd > STDERR_FILENO) {
-            if(close(fd) < 0) {
-                perror("close");
-                return true;
-            }
-        }
-    }
-    return false; 
+      /* parent */
+      int exit_code= -1;
+      int status;
+      while (waitpid(child, &status, 0) != child)
+      { }
+
+      if (WIFEXITED(status))
+      {
+        exit_code= WEXITSTATUS(status);
+      }
+      if (WIFSIGNALED(status))
+      {
+        exit_code= -1;
+      }
+      _exit(exit_code);
+    }
+  }
+
+  /* child */
+  if (setsid() == -1)
+  {
+    return true;
+  }
+
+  return false; 
 }
 
 } /* namespace drizzled */

=== modified file 'drizzled/daemon.h'
--- drizzled/daemon.h	2011-03-14 05:40:28 +0000
+++ drizzled/daemon.h	2011-07-18 17:13:07 +0000
@@ -36,7 +36,7 @@
 namespace drizzled
 {
 
-bool daemonize(bool nochdir= true, bool noclose= true, bool wait_sigusr1= true);
+bool daemonize();
 void daemon_is_ready();
 
 }

=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2011-07-18 02:56:15 +0000
+++ drizzled/drizzled.cc	2011-07-18 17:13:07 +0000
@@ -469,7 +469,7 @@
 void unireg_actual_abort(const char *file, int line, const char *func, const std::string& message)
 {
   std::stringstream temp;
-  temp << _("Aborting:") << "\"" << message << "\"" << " at " << file << ":" << line << " in " << func << "()";
+  temp << _("Aborting:") << "\"" << message << "\"" << ". Abort was called from " << file << ":" << line << " in " << func << "()";
   errmsg_printf(error::ERROR, temp.str().c_str());
 
   clean_up(opt_help == false);

=== modified file 'drizzled/main.cc'
--- drizzled/main.cc	2011-07-18 02:56:15 +0000
+++ drizzled/main.cc	2011-07-18 17:13:07 +0000
@@ -393,7 +393,9 @@
   }
 
   if (opt_daemon)
+  {
     daemon_is_ready();
+  }
 
   /*
     Listen for new connections and start new session for each connection

